.. Affective Research Dataset Toolkit documentation master file, created by
   sphinx-quickstart on Wed Mar 19 13:07:36 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Affective Research Dataset Toolkit (ARDT)
=========================================

Welcome
-------

ARDT, pronouced "_art_," is a utility library for working with AER Datasets available to the academic community for research in
automated emotion recognition. While it may likely be applied to datasets in other research areas, the author(s)'
are primarily focused on AER.

Start with `the quick start guide <user_guide/index.html>`_, or dive deep in the `API reference guide <reference/index.html>`_.

.. toctree::
    :hidden:
    :titlesonly:

    user_guide/index
    reference/index
    changelog